@@ -20,6 +20,7 @@ from typing import (
     Tuple,
     TypeVar,
     Union,
+    cast,
 )
 from urllib.parse import parse_qs, parse_qsl, urlparse
 from xml.dom.minidom import parseString as parseXML
@@ -33,6 +34,8 @@ from werkzeug.exceptions import HTTPException
 from moto import settings
 from moto.core.common_types import TYPE_IF_NONE, TYPE_RESPONSE
 from moto.core.exceptions import DryRunClientError, ServiceException
+from moto.core.parsers import PROTOCOL_PARSERS, XFormedDict
+from moto.core.request import normalize_request
 from moto.core.serialize import SERIALIZERS, ResponseSerializer, XFormedAttributePicker
 from moto.core.utils import (
     camelcase_to_underscores,
@@ -101,12 +104,16 @@ def _get_method_urls(service_name: str, region: str) -> Dict[str, Dict[str, str]
             # Terraform 5.51+ makes a request to /rrset - so we have to intercept both variants
             request_uri += "?"
         if service_name == "lambda":
-            if request_uri.endswith("/event-source-mappings/"):
-                # AWS GO SDK behaves differently from other SDK's, does not send a trailing slash
-                request_uri += "?"
-            elif request_uri.endswith("/functions/"):
-                # AWS JS SDK behaves differently from other SDK's, does not send a trailing slash
-                request_uri += "?"
+            # Several operations have inconsistent trailing slashes across Botocore versions.
+            affected_operations = [
+                "CreateEventSourceMapping",
+                "CreateFunction",
+                "InvokeAsync",
+                "ListEventSourceMappings",
+                "ListFunctions",
+            ]
+            if op_name in affected_operations:
+                request_uri += "?" if request_uri.endswith("/") else "/?"
         if service_name == "opensearch" and request_uri.endswith("/tags/"):
             # AWS GO SDK behaves differently from other SDK's, does not send a trailing slash
             request_uri += "?"
@@ -349,6 +356,7 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
         super().__init__()
         self.service_name = service_name
         self.allow_request_decompression = True
+        self.automated_parameter_parsing = False
 
     @classmethod
     def dispatch(cls, *args: Any, **kwargs: Any) -> Any:  # type: ignore[misc]
@@ -503,6 +511,9 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
             "date": datetime.datetime.now().strftime("%a, %d %b %Y %H:%M:%S GMT"),
         }
 
+        if self.automated_parameter_parsing:
+            self.parse_parameters(request)
+
         # Register visit with IAM
         from moto.iam.models import mark_account_as_visited
 
@@ -630,6 +641,22 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
         # get action from method and uri
         return self._get_action_from_method_and_request_uri(self.method, self.raw_path)
 
+    def parse_parameters(self, request: Any) -> None:
+        from botocore.awsrequest import AWSPreparedRequest
+        from werkzeug import Request
+
+        assert isinstance(request, (AWSPreparedRequest, Request)), str(request)
+        normalized_request = normalize_request(request)
+        service_model = get_service_model(self.service_name)
+        operation_model = service_model.operation_model(self._get_action())
+        protocol = service_model.protocol
+        parser_cls = PROTOCOL_PARSERS[protocol]
+        parser = parser_cls(map_type=XFormedDict)  # type: ignore[no-untyped-call]
+        parsed = parser.parse(
+            {"query_params": normalized_request.values}, operation_model
+        )  # type: ignore[no-untyped-call]
+        self.params = cast(Any, parsed)
+
     def serialized(self, action_result: ActionResult) -> TYPE_RESPONSE:
         service_model = get_service_model(self.service_name)
         operation_model = service_model.operation_model(self._get_action())
@@ -665,7 +692,9 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
             try:
                 response = method()
             except ServiceException as e:
-                response = ActionResult(e)  # type: ignore[assignment]
+                se_status, se_headers, se_body = self.serialized(ActionResult(e))
+                se_headers["status"] = se_status
+                response = se_body, se_headers  # type: ignore[assignment]
             except HTTPException as http_error:
                 response_headers: Dict[str, Union[str, int]] = dict(
                     http_error.get_headers() or []
@@ -918,6 +947,8 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
             ]
         }
         """
+        if self.automated_parameter_parsing:
+            return self.params
         params: Dict[str, Any] = {}
         for k, v in sorted(self.querystring.items(), key=params_sort_function):
             self._parse_param(k, v[0], params)
