@@ -1,10 +1,20 @@
 from typing import Any, Dict, Iterator, List, Optional, Tuple
 
 from moto.acm.models import AWSCertificateManagerBackend, acm_backends
+from moto.appsync.models import AppSyncBackend, appsync_backends
 from moto.awslambda.models import LambdaBackend, lambda_backends
 from moto.backup.models import BackupBackend, backup_backends
+from moto.clouddirectory import CloudDirectoryBackend, clouddirectory_backends
+from moto.cloudfront.models import CloudFrontBackend, cloudfront_backends
+from moto.cloudwatch.models import CloudWatchBackend, cloudwatch_backends
+from moto.comprehend.models import ComprehendBackend, comprehend_backends
+from moto.connectcampaigns.models import (
+    ConnectCampaignServiceBackend,
+    connectcampaigns_backends,
+)
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.exceptions import RESTError
+from moto.dms.models import DatabaseMigrationServiceBackend, dms_backends
 from moto.dynamodb.models import DynamoDBBackend, dynamodb_backends
 from moto.ec2 import ec2_backends
 from moto.ecs.models import EC2ContainerServiceBackend, ecs_backends
@@ -12,10 +22,15 @@ from moto.efs.models import EFSBackend, efs_backends
 from moto.elb.models import ELBBackend, elb_backends
 from moto.elbv2.models import ELBv2Backend, elbv2_backends
 from moto.emr.models import ElasticMapReduceBackend, emr_backends
+from moto.events.models import EventsBackend, events_backends
 from moto.glacier.models import GlacierBackend, glacier_backends
 from moto.glue.models import GlueBackend, glue_backends
 from moto.kafka.models import KafkaBackend, kafka_backends
 from moto.kinesis.models import KinesisBackend, kinesis_backends
+from moto.kinesisanalyticsv2.models import (
+    KinesisAnalyticsV2Backend,
+    kinesisanalyticsv2_backends,
+)
 from moto.kms.models import KmsBackend, kms_backends
 from moto.lexv2models.models import LexModelsV2Backend, lexv2models_backends
 from moto.logs.models import LogsBackend, logs_backends
@@ -35,7 +50,7 @@ from moto.utilities.utils import get_partition
 from moto.workspaces.models import WorkSpacesBackend, workspaces_backends
 from moto.workspacesweb.models import WorkSpacesWebBackend, workspacesweb_backends
 
-# Left: EC2 ElastiCache RDS ELB CloudFront Lambda EMR Glacier Kinesis Redshift Route53
+# Left: EC2 ElastiCache RDS ELB Lambda EMR Glacier Kinesis Redshift Route53
 # StorageGateway DynamoDB MachineLearning ACM DirectConnect DirectoryService CloudHSM
 # Inspector Elasticsearch
 
@@ -50,10 +65,18 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
         # fit in the current request. As we only store generators
         # there is really no point cleaning up
 
+    @property
+    def appsync_backend(self) -> AppSyncBackend:
+        return appsync_backends[self.account_id][self.region_name]
+
     @property
     def s3_backend(self) -> S3Backend:
         return s3_backends[self.account_id][self.partition]
 
+    @property
+    def dms_backend(self) -> DatabaseMigrationServiceBackend:
+        return dms_backends[self.account_id][self.region_name]
+
     @property
     def ec2_backend(self) -> Any:  # type: ignore[misc]
         return ec2_backends[self.account_id][self.region_name]
@@ -70,6 +93,10 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
     def elbv2_backend(self) -> ELBv2Backend:
         return elbv2_backends[self.account_id][self.region_name]
 
+    @property
+    def events_backend(self) -> EventsBackend:
+        return events_backends[self.account_id][self.region_name]
+
     @property
     def glue_backend(self) -> GlueBackend:
         return glue_backends[self.account_id][self.region_name]
@@ -78,6 +105,10 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
     def kinesis_backend(self) -> KinesisBackend:
         return kinesis_backends[self.account_id][self.region_name]
 
+    @property
+    def kinesisanalyticsv2_backend(self) -> KinesisAnalyticsV2Backend:
+        return kinesisanalyticsv2_backends[self.account_id][self.region_name]
+
     @property
     def kms_backend(self) -> KmsBackend:
         return kms_backends[self.account_id][self.region_name]
@@ -156,6 +187,13 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
             return workspacesweb_backends[self.account_id][self.region_name]
         return None
 
+    @property
+    def comprehend_backend(self) -> Optional[ComprehendBackend]:
+        # aws Comprehend has limited region availability
+        if self.region_name in comprehend_backends[self.account_id].regions:
+            return comprehend_backends[self.account_id][self.region_name]
+        return None
+
     @property
     def kafka_backend(self) -> KafkaBackend:
         return kafka_backends[self.account_id][self.region_name]
@@ -170,6 +208,27 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
             return lexv2models_backends[self.account_id][self.region_name]
         return None
 
+    @property
+    def clouddirectory_backend(self) -> Optional[CloudDirectoryBackend]:
+        if self.region_name in clouddirectory_backends[self.account_id].regions:
+            return clouddirectory_backends[self.account_id][self.region_name]
+        return None
+
+    @property
+    def cloudfront_backend(self) -> CloudFrontBackend:
+        return cloudfront_backends[self.account_id][self.partition]
+
+    @property
+    def cloudwatch_backend(self) -> CloudWatchBackend:
+        return cloudwatch_backends[self.account_id][self.region_name]
+
+    @property
+    def connectcampaigns_backend(self) -> Optional[ConnectCampaignServiceBackend]:
+        # Connect Campaigns service has limited region availability
+        if self.region_name in connectcampaigns_backends[self.account_id].regions:
+            return connectcampaigns_backends[self.account_id][self.region_name]
+        return None
+
     def _get_resources_generator(
         self,
         tag_filters: Optional[List[Dict[str, Any]]] = None,
@@ -233,6 +292,19 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
                     continue
                 yield {"ResourceARN": f"{certificate.arn}", "Tags": tags}
 
+        # AppSync
+        if not resource_type_filters or "appsync" in resource_type_filters:
+            for api in self.appsync_backend.graphql_apis.values():
+                tags = self.appsync_backend.tagger.list_tags_for_resource(api.arn)[
+                    "Tags"
+                ]
+                if not tags or not tag_filter(
+                    tags
+                ):  # Skip if no tags, or invalid filter
+                    continue
+
+                yield {"ResourceARN": f"{api.arn}", "Tags": tags}
+
         # Backup
         if not resource_type_filters or "backup" in resource_type_filters:
             for vault in self.backup_backend.vaults.values():
@@ -246,6 +318,31 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
 
                 yield {"ResourceARN": f"{vault.backup_vault_arn}", "Tags": tags}
 
+        # Comprehend
+        if self.comprehend_backend:
+            if not resource_type_filters or "comprehend" in resource_type_filters:
+                for document_classifier in self.comprehend_backend.classifiers.values():
+                    tags = self.comprehend_backend.tagger.list_tags_for_resource(
+                        document_classifier.arn
+                    )["Tags"]
+                    if not tags or not tag_filter(tags):
+                        continue
+                    yield {
+                        "ResourceARN": f"{document_classifier.arn}",
+                        "Tags": tags,
+                    }
+
+                for entity_recognizer in self.comprehend_backend.recognizers.values():
+                    tags = self.comprehend_backend.tagger.list_tags_for_resource(
+                        entity_recognizer.arn
+                    )["Tags"]
+                    if not tags or not tag_filter(tags):
+                        continue
+                    yield {
+                        "ResourceARN": f"{entity_recognizer.arn}",
+                        "Tags": tags,
+                    }
+
         # S3
         if (
             not resource_type_filters
@@ -260,6 +357,20 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
                     continue
                 yield {"ResourceARN": bucket.arn, "Tags": tags}
 
+        # Cloud Directory
+        if self.clouddirectory_backend:
+            if not resource_type_filters or "clouddirectory" in resource_type_filters:
+                clouddirectory_backend = clouddirectory_backends[self.account_id][
+                    self.region_name
+                ]
+                for directory in clouddirectory_backend.directories.values():
+                    tags = clouddirectory_backend.tagger.list_tags_for_resource(
+                        directory.directory_arn
+                    )["Tags"]
+                    if not tags or not tag_filter(tags):
+                        continue
+                    yield {"ResourceARN": f"{directory.directory_arn}", "Tags": tags}
+
         # CloudFormation
         if not resource_type_filters or "cloudformation:stack" in resource_type_filters:
             try:
@@ -276,6 +387,87 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
             except Exception:
                 pass
 
+        # Cloudfront
+        if (
+            not resource_type_filters
+            or "cloudfront" in resource_type_filters
+            or "cloudfront:distributions" in resource_type_filters
+        ):
+            for dist in self.cloudfront_backend.distributions.values():
+                tags = self.cloudfront_backend.tagger.list_tags_for_resource(dist.arn)[
+                    "Tags"
+                ]
+                if (
+                    not tag_filter(tags) or len(tags) == 0
+                ):  # Skip if no tags, or invalid filter
+                    continue
+                yield {"ResourceARN": f"{dist.arn}", "Tags": tags}
+
+        if self.cloudwatch_backend:
+            cloudwatch_resource_map: Dict[str, Dict[str, Any]] = {
+                "cloudwatch:alarm": self.cloudwatch_backend.alarms,
+                "cloudwatch:insight-rule": self.cloudwatch_backend.insight_rules,
+            }
+            for resource_type, resource_source in cloudwatch_resource_map.items():
+                if (
+                    not resource_type_filters
+                    or "cloudwatch" in resource_type_filters
+                    or resource_type in resource_type_filters
+                ):
+                    for resource in resource_source.values():
+                        if resource_type == "cloudwatch:alarm":
+                            end_of_arn = f"alarm:{resource.name}"
+                        elif resource_type == "cloudwatch:insight-rule":
+                            end_of_arn = f"insight-rule/{resource.name}"
+
+                        arn = f"arn:{get_partition(self.region_name)}:cloudwatch:{self.region_name}:{self.account_id}:{end_of_arn}"
+
+                        cw_tags = self.cloudwatch_backend.list_tags_for_resource(arn)
+
+                        tags = format_tags(cw_tags)
+                        if not tags or not tag_filter(tags):
+                            continue
+                        yield {
+                            "ResourceARN": arn,
+                            "Tags": tags,
+                        }
+
+        # Connect Campaigns v1
+        if self.connectcampaigns_backend:
+            if not resource_type_filters or "connectcampaigns" in resource_type_filters:
+                connectcampaigns_backend: ConnectCampaignServiceBackend = (
+                    connectcampaigns_backends[self.account_id][self.region_name]
+                )
+                for campaign in connectcampaigns_backend.campaigns.values():
+                    tags = connectcampaigns_backend.tagger.list_tags_for_resource(
+                        campaign.arn
+                    )["Tags"]
+                    if not tags or not tag_filter(tags):
+                        continue
+                    yield {"ResourceARN": f"{campaign.arn}", "Tags": tags}
+
+        # DMS
+        if not resource_type_filters or "dms:endpoint" in resource_type_filters:
+            for endpoint in self.dms_backend.endpoints.values():
+                tags = self.dms_backend.tagger.list_tags_for_resource(
+                    endpoint.endpoint_arn
+                )["Tags"]
+                if not tag_filter(tags):
+                    continue
+                yield {"ResourceARN": f"{endpoint.endpoint_arn}", "Tags": tags}
+
+        if (
+            not resource_type_filters
+            or "dms:replication-instance" in resource_type_filters
+        ):
+            for replication_instance in self.dms_backend.replication_instances.values():
+                tags = self.dms_backend.tagger.list_tags_for_resource(
+                    replication_instance.arn
+                )["Tags"]
+                if not tag_filter(tags):
+                    continue
+                yield {"ResourceARN": f"{replication_instance.arn}", "Tags": tags}
+
         # ECS
         if not resource_type_filters or "ecs:service" in resource_type_filters:
             for service in self.ecs_backend.services.values():
@@ -299,6 +491,14 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
                         continue
                     yield {"ResourceARN": f"{task.task_arn}", "Tags": tags}
 
+        if not resource_type_filters or "ecs:task-definition" in resource_type_filters:
+            for task_definition_dict in self.ecs_backend.task_definitions.values():
+                for task_definition in task_definition_dict.values():
+                    tags = format_tag_keys(task_definition.tags, ["key", "value"])
+                    if not tag_filter(tags):
+                        continue
+                    yield {"ResourceARN": f"{task_definition.arn}", "Tags": tags}
+
         # EC2 Resources
         ec2_resource_types = {
             "ec2:image": self.ec2_backend.amis.values(),
@@ -423,6 +623,22 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
 
         # EMR Cluster
 
+        # Events
+        if (
+            not resource_type_filters
+            or "events" in resource_type_filters
+            or "events:event-bus" in resource_type_filters
+        ):
+            for bus in self.events_backend.event_buses.values():
+                tags = self.events_backend.tagger.list_tags_for_resource(bus.arn)[
+                    "Tags"
+                ]
+                if (
+                    not tag_filter(tags) or len(tags) == 0
+                ):  # Skip if no tags, or invalid filter
+                    continue
+                yield {"ResourceARN": f"{bus.arn}", "Tags": tags}
+
         # Glacier Vault
 
         # Glue
@@ -450,6 +666,21 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
 
         # Kinesis
 
+        # KinesisAnalyticsV2
+        if self.kinesisanalyticsv2_backend and (
+            not resource_type_filters or "kinesisanalyticsv2" in resource_type_filters
+        ):
+            for application in self.kinesisanalyticsv2_backend.applications.values():
+                tags = self.kinesisanalyticsv2_backend.tagger.list_tags_for_resource(
+                    application.application_arn
+                )["Tags"]
+                if not tags or not tag_filter(tags):
+                    continue
+                yield {
+                    "ResourceARN": application.application_arn,
+                    "Tags": tags,
+                }
+
         # KMS
         if not resource_type_filters or "kms" in resource_type_filters:
             for kms_key in self.kms_backend.list_keys():
@@ -475,7 +706,11 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
                     or resource_type in resource_type_filters
                 ):
                     for resource in resource_source.values():
-                        tags = format_tags(resource.tags)
+                        bot_tags = self.lexv2_backend.list_tags_for_resource(
+                            resource.arn
+                        )
+
+                        tags = format_tags(bot_tags)
                         if not tags or not tag_filter(tags):
                             continue
                         yield {
@@ -499,11 +734,11 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
                 yield {"ResourceARN": group.arn, "Tags": tags}
 
         # RDS resources
-        resource_map: Dict[str, Dict[str, Any]] = {
-            "rds:cluster": self.rds_backend.clusters,
-            "rds:db": self.rds_backend.databases,
-            "rds:snapshot": self.rds_backend.database_snapshots,
-            "rds:cluster-snapshot": self.rds_backend.cluster_snapshots,
+        resource_map: dict[str, dict[str, Any]] = {
+            "rds:cluster": dict(self.rds_backend.clusters),
+            "rds:db": dict(self.rds_backend.databases),
+            "rds:snapshot": dict(self.rds_backend.database_snapshots),
+            "rds:cluster-snapshot": dict(self.rds_backend.cluster_snapshots),
             "rds:db-proxy": self.rds_backend.db_proxies,
         }
         for resource_type, resource_source in resource_map.items():
@@ -590,7 +825,15 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
         # Step Functions
         if not resource_type_filters or "states:stateMachine" in resource_type_filters:
             for state_machine in self.stepfunctions_backend.state_machines:
-                tags = format_tag_keys(state_machine.tags, ["key", "value"])
+                tags = format_tag_keys(
+                    state_machine.backend.get_tags_list_for_state_machine(
+                        state_machine.arn
+                    ),
+                    [
+                        state_machine.backend.tagger.key_name,
+                        state_machine.backend.tagger.value_name,
+                    ],
+                )
                 if not tags or not tag_filter(tags):
                     continue
                 yield {"ResourceARN": state_machine.arn, "Tags": tags}
