@@ -7,21 +7,22 @@ from email.mime.multipart import MIMEMultipart
 from email.utils import formataddr, getaddresses, parseaddr
 from typing import Any, Dict, List, Optional
 
-from moto.core import BackendDict, BaseBackend, BaseModel
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel
 from moto.core.utils import utcnow
 from moto.sns.models import sns_backends
+from moto.utilities.paginator import paginate
 
 from .exceptions import (
+    AlreadyExists,
     ConfigurationSetAlreadyExists,
     ConfigurationSetDoesNotExist,
     EventDestinationAlreadyExists,
     InvalidParameterValue,
     InvalidRenderingParameterException,
     MessageRejectedError,
-    RuleAlreadyExists,
     RuleDoesNotExist,
     RuleSetDoesNotExist,
-    RuleSetNameAlreadyExists,
     TemplateDoesNotExist,
     TemplateNameAlreadyExists,
     ValidationError,
@@ -32,6 +33,15 @@ from .utils import get_random_message_id, is_valid_address
 
 RECIPIENT_LIMIT = 50
 
+PAGINATION_MODEL = {
+    "list_configuration_sets": {
+        "input_token": "next_token",
+        "limit_key": "max_items",
+        "limit_default": 100,
+        "unique_attribute": "configuration_set_name",
+    },
+}
+
 
 class SESFeedback(BaseModel):
     BOUNCE = "Bounce"
@@ -122,11 +132,45 @@ class RawMessage(BaseModel):
 
 class SESQuota(BaseModel):
     def __init__(self, sent: int):
-        self.sent = sent
+        self.sent_last24_hours = sent
+        self.max24_hour_send = 200
+        self.max_send_rate = 1
 
-    @property
-    def sent_past_24(self) -> int:
-        return self.sent
+
+class ConfigurationSet(BaseModel):
+    def __init__(
+        self,
+        configuration_set_name: str,
+        tracking_options: Optional[Dict[str, str]] = {},
+        delivery_options: Optional[Dict[str, Any]] = {},
+        reputation_options: Optional[Dict[str, Any]] = {},
+        sending_options: Optional[Dict[str, bool]] = {},
+        tags: Optional[List[Dict[str, str]]] = [],
+        suppression_options: Optional[Dict[str, List[str]]] = {},
+        vdm_options: Optional[Dict[str, Dict[str, str]]] = {},
+    ) -> None:
+        # Shared between SES and SESv2
+        self.configuration_set_name = configuration_set_name
+        self.tracking_options = tracking_options
+        self.delivery_options = delivery_options
+        self.reputation_options = reputation_options
+        self.enabled = sending_options  # Enabled in v1, SendingOptions in v2
+        # SESv2 specific fields
+        self.tags = tags
+        self.suppression_options = suppression_options
+        self.vdm_options = vdm_options
+
+    def to_dict_v2(self) -> Dict[str, Any]:
+        return {
+            "ConfigurationSetName": self.configuration_set_name,
+            "TrackingOptions": self.tracking_options,
+            "DeliveryOptions": self.delivery_options,
+            "ReputationOptions": self.reputation_options,
+            "SendingOptions": {"SendingEnabled": self.enabled},
+            "Tags": self.tags,
+            "SuppressionOptions": self.suppression_options,
+            "VdmOptions": self.vdm_options,
+        }
 
 
 class SESBackend(BaseBackend):
@@ -154,12 +198,13 @@ class SESBackend(BaseBackend):
         self.sent_message_count = 0
         self.rejected_messages_count = 0
         self.sns_topics: Dict[str, Dict[str, Any]] = {}
-        self.config_set: Dict[str, int] = {}
+        self.config_sets: Dict[str, ConfigurationSet] = {}
         self.config_set_event_destination: Dict[str, Dict[str, Any]] = {}
         self.event_destinations: Dict[str, int] = {}
         self.identity_mail_from_domains: Dict[str, Dict[str, Any]] = {}
         self.templates: Dict[str, Dict[str, str]] = {}
         self.receipt_rule_set: Dict[str, List[Dict[str, Any]]] = {}
+        self.dkim_tokens: Dict[str, List[str]] = {}
 
     def _is_verified_address(self, source: str) -> bool:
         _, address = parseaddr(source)
@@ -357,7 +402,9 @@ class SESBackend(BaseBackend):
                     f"Did not have authority to send from email {source}"
                 )
 
-        fieldvalues = [message.get(header, "") for header in ["TO", "CC", "BCC"]]
+        fieldvalues = [
+            message[header] for header in ["TO", "CC", "BCC"] if header in message
+        ]
         destinations += [
             formataddr((realname, email_address))
             for realname, email_address in getaddresses(fieldvalues)
@@ -386,7 +433,13 @@ class SESBackend(BaseBackend):
     ) -> Dict[str, Dict[str, Any]]:
         response: Dict[str, Dict[str, Any]] = {}
         for identity in identities:
-            response[identity] = self.sns_topics.get(identity, {})
+            config = self.sns_topics.get(identity, {})
+            response[identity] = {
+                "ForwardingEnabled": config.get("feedback_forwarding_enabled", True),
+                "HeadersInBounceNotificationsEnabled": False,
+                "HeadersInComplaintNotificationsEnabled": False,
+                "HeadersInDeliveryNotificationsEnabled": False,
+            }
         return response
 
     def set_identity_feedback_forwarding_enabled(
@@ -408,22 +461,63 @@ class SESBackend(BaseBackend):
         self.sns_topics[identity] = identity_sns_topics
 
     def create_configuration_set(self, configuration_set_name: str) -> None:
-        if configuration_set_name in self.config_set:
+        if configuration_set_name in self.config_sets:
             raise ConfigurationSetAlreadyExists(
                 f"Configuration set <{configuration_set_name}> already exists"
             )
-        self.config_set[configuration_set_name] = 1
+        config_set = ConfigurationSet(configuration_set_name=configuration_set_name)
+        self.config_sets[configuration_set_name] = config_set
 
-    def describe_configuration_set(self, configuration_set_name: str) -> None:
-        if configuration_set_name not in self.config_set:
+    def create_configuration_set_v2(
+        self,
+        configuration_set_name: str,
+        tracking_options: Dict[str, str],
+        delivery_options: Dict[str, Any],
+        reputation_options: Dict[str, Any],
+        sending_options: Dict[str, bool],
+        tags: List[Dict[str, str]],
+        suppression_options: Dict[str, List[str]],
+        vdm_options: Dict[str, Dict[str, str]],
+    ) -> None:
+        if configuration_set_name in self.config_sets:
+            raise ConfigurationSetAlreadyExists(
+                f"Configuration set <{configuration_set_name}> already exists"
+            )
+        new_config_set = ConfigurationSet(
+            configuration_set_name=configuration_set_name,
+            tracking_options=tracking_options,
+            delivery_options=delivery_options,
+            reputation_options=reputation_options,
+            sending_options=sending_options,
+            tags=tags,
+            suppression_options=suppression_options,
+            vdm_options=vdm_options,
+        )
+        self.config_sets[configuration_set_name] = new_config_set
+
+    def describe_configuration_set(
+        self, configuration_set_name: str
+    ) -> ConfigurationSet:
+        if configuration_set_name not in self.config_sets:
             raise ConfigurationSetDoesNotExist(
                 f"Configuration set <{configuration_set_name}> does not exist"
             )
+        return self.config_sets[configuration_set_name]
+
+    def delete_configuration_set(self, configuration_set_name: str) -> None:
+        self.config_sets.pop(configuration_set_name)
+
+    @paginate(pagination_model=PAGINATION_MODEL)
+    def list_configuration_sets(self) -> List[ConfigurationSet]:
+        return list(self.config_sets.values())
+
+    def _list_all_configuration_sets(self) -> List[ConfigurationSet]:
+        return list(self.config_sets.values())
 
     def create_configuration_set_event_destination(
         self, configuration_set_name: str, event_destination: Dict[str, Any]
     ) -> None:
-        if self.config_set.get(configuration_set_name) is None:
+        if self.config_sets.get(configuration_set_name) is None:
             raise ConfigurationSetDoesNotExist("Invalid Configuration Set Name.")
 
         if self.event_destinations.get(event_destination["Name"]):
@@ -529,15 +623,15 @@ class SESBackend(BaseBackend):
 
     def create_receipt_rule_set(self, rule_set_name: str) -> None:
         if self.receipt_rule_set.get(rule_set_name) is not None:
-            raise RuleSetNameAlreadyExists("Duplicate Receipt Rule Set Name.")
+            raise AlreadyExists(f"Rule set already exists: {rule_set_name}")
         self.receipt_rule_set[rule_set_name] = []
 
     def create_receipt_rule(self, rule_set_name: str, rule: Dict[str, Any]) -> None:
         rule_set = self.receipt_rule_set.get(rule_set_name)
         if rule_set is None:
-            raise RuleSetDoesNotExist("Invalid Rule Set Name.")
+            raise RuleSetDoesNotExist(f"Rule set does not exist: {rule_set_name}")
         if rule in rule_set:
-            raise RuleAlreadyExists("Duplicate Rule Name.")
+            raise AlreadyExists(f"Rule already exists: {rule['name']}")
         rule_set.append(rule)
         self.receipt_rule_set[rule_set_name] = rule_set
 
@@ -555,13 +649,13 @@ class SESBackend(BaseBackend):
         rule_set = self.receipt_rule_set.get(rule_set_name)
 
         if rule_set is None:
-            raise RuleSetDoesNotExist("Invalid Rule Set Name.")
+            raise RuleSetDoesNotExist(f"Rule set does not exist: {rule_set_name}")
 
         for receipt_rule in rule_set:
             if receipt_rule["name"] == rule_name:
                 return receipt_rule
 
-        raise RuleDoesNotExist("Invalid Rule Name.")
+        raise RuleDoesNotExist(f"Rule does not exist: {rule_name}")
 
     def update_receipt_rule(self, rule_set_name: str, rule: Dict[str, Any]) -> None:
         rule_set = self.receipt_rule_set.get(rule_set_name)
@@ -613,28 +707,78 @@ class SESBackend(BaseBackend):
     ) -> Dict[str, Dict[str, str]]:
         if identities is None:
             identities = []
-
         attributes_by_identity = {}
         for identity in identities:
             if identity in (self.domains + self.addresses):
-                attributes_by_identity[identity] = self.identity_mail_from_domains.get(
-                    identity
-                ) or {"behavior_on_mx_failure": "UseDefaultValue"}
-
+                value = self.identity_mail_from_domains.get(identity, {})
+                mail_from_domain = value.get("mail_from_domain")
+                attributes_by_identity[identity] = {
+                    "MailFromDomain": mail_from_domain,
+                    "MailFromDomainStatus": "Success" if mail_from_domain else None,
+                    "BehaviorOnMXFailure": value.get(
+                        "behavior_on_mx_failure", "UseDefaultValue"
+                    ),
+                }
         return attributes_by_identity
 
     def get_identity_verification_attributes(
         self, identities: Optional[List[str]] = None
-    ) -> Dict[str, str]:
+    ) -> Dict[str, Dict[str, str]]:
         if identities is None:
             identities = []
-
-        attributes_by_identity: Dict[str, str] = {}
+        attributes_by_identity = {}
         for identity in identities:
             if identity in (self.domains + self.addresses):
-                attributes_by_identity[identity] = "Success"
-
+                attributes_by_identity[identity] = {
+                    "VerificationStatus": "Success",
+                    "VerificationToken": "ILQMESfEW0p6i6gIJcEWvO65TP5hg6B99hGFZ2lxrIs=",
+                }
         return attributes_by_identity
 
+    def update_configuration_set_reputation_metrics_enabled(
+        self, configuration_set_name: str, enabled: bool
+    ) -> None:
+        if configuration_set_name not in self.config_sets:
+            raise ConfigurationSetDoesNotExist(
+                f"Configuration set <{configuration_set_name}> does not exist"
+            )
+        config_set = self.config_sets[configuration_set_name]
+        if config_set.reputation_options is None:
+            config_set.reputation_options = {}
+        config_set.reputation_options["ReputationMetricsEnabled"] = enabled
+
+    def get_identity_dkim_attributes(
+        self, identities: List[str]
+    ) -> Dict[str, Dict[str, Any]]:
+        result = {}
+        for identity in identities:
+            is_domain = "@" not in identity
+            dkim_enabled = True
+            verification_status = (
+                "Success"
+                if identity in (self.domains + self.addresses)
+                else "NotStarted"
+            )
+
+            dkim_data = {
+                "DkimEnabled": dkim_enabled,
+                "DkimVerificationStatus": verification_status,
+            }
+
+            # Only include tokens for domain identities
+            if is_domain and verification_status == "Success":
+                if identity not in self.dkim_tokens:
+                    # Generate new DKIM tokens for the domain
+                    self.dkim_tokens[identity] = [
+                        "vvjuipp74whm76gqoni7qmwwn4w4qusjiainivf6sf",
+                        "3frqe7jn4obpuxjpwpolz6ipb3k5nvt2nhjpik2oy",
+                        "wrqplteh7oodxnad7hsl4mixg2uavzneazxv5sxi2",
+                    ]
+                dkim_data["DkimTokens"] = self.dkim_tokens[identity]
+
+            result[identity] = dkim_data
+
+        return result
+
 
 ses_backends = BackendDict(SESBackend, "ses")
