@@ -6,13 +6,13 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_ec2, settings
+from moto import mock_aws, settings
 
 SAMPLE_DOMAIN_NAME = "example.com"
 SAMPLE_NAME_SERVERS = ["10.0.0.6", "10.0.0.7"]
 
 
-@mock_ec2
+@mock_aws
 def test_dhcp_options_associate():
     """associate dhcp option"""
     ec2 = boto3.resource("ec2", region_name="us-west-1")
@@ -32,7 +32,7 @@ def test_dhcp_options_associate():
     assert vpc.dhcp_options_id == dhcp_options.id
 
 
-@mock_ec2
+@mock_aws
 def test_dhcp_options_associate_invalid_dhcp_id():
     """associate dhcp option bad dhcp options id"""
     ec2 = boto3.resource("ec2", region_name="us-west-1")
@@ -46,7 +46,7 @@ def test_dhcp_options_associate_invalid_dhcp_id():
     assert ex.value.response["Error"]["Code"] == "InvalidDhcpOptionID.NotFound"
 
 
-@mock_ec2
+@mock_aws
 def test_dhcp_options_associate_invalid_vpc_id():
     """associate dhcp option invalid vpc id"""
     ec2 = boto3.resource("ec2", region_name="us-west-1")
@@ -65,7 +65,7 @@ def test_dhcp_options_associate_invalid_vpc_id():
     assert ex.value.response["Error"]["Code"] == "InvalidVpcID.NotFound"
 
 
-@mock_ec2
+@mock_aws
 def test_dhcp_options_disassociation():
     """Ensure that VPCs can be set to the 'default' DHCP options set for disassociation."""
     ec2 = boto3.resource("ec2", region_name="us-west-1")
@@ -93,7 +93,7 @@ def test_dhcp_options_disassociation():
     assert vpc.dhcp_options_id == "default"
 
 
-@mock_ec2
+@mock_aws
 def test_dhcp_options_delete_with_vpc():
     """Test deletion of dhcp options with vpc"""
     ec2 = boto3.resource("ec2", region_name="us-west-1")
@@ -123,7 +123,7 @@ def test_dhcp_options_delete_with_vpc():
     assert ex.value.response["Error"]["Code"] == "InvalidDhcpOptionID.NotFound"
 
 
-@mock_ec2
+@mock_aws
 def test_create_dhcp_options():
     """Create most basic dhcp option"""
     ec2 = boto3.resource("ec2", region_name="us-west-1")
@@ -144,7 +144,7 @@ def test_create_dhcp_options():
     assert {"Key": "domain-name", "Values": [{"Value": SAMPLE_DOMAIN_NAME}]} in config
 
 
-@mock_ec2
+@mock_aws
 def test_create_dhcp_options_invalid_options():
     """Create invalid dhcp options"""
     ec2 = boto3.resource("ec2", region_name="us-west-1")
@@ -167,7 +167,7 @@ def test_create_dhcp_options_invalid_options():
     assert ex.value.response["Error"]["Code"] == "InvalidParameterValue"
 
 
-@mock_ec2
+@mock_aws
 def test_describe_dhcp_options():
     """Test dhcp options lookup by id"""
     ec2 = boto3.resource("ec2", region_name="us-west-1")
@@ -199,7 +199,7 @@ def test_describe_dhcp_options():
     assert {"Key": "domain-name", "Values": [{"Value": SAMPLE_DOMAIN_NAME}]} in config
 
 
-@mock_ec2
+@mock_aws
 def test_describe_dhcp_options_invalid_id():
     """get error on invalid dhcp_option_id lookup"""
     client = boto3.client("ec2", region_name="us-west-1")
@@ -211,7 +211,7 @@ def test_describe_dhcp_options_invalid_id():
     assert ex.value.response["Error"]["Code"] == "InvalidDhcpOptionID.NotFound"
 
 
-@mock_ec2
+@mock_aws
 def test_delete_dhcp_options():
     """delete dhcp option"""
     ec2 = boto3.resource("ec2", region_name="us-west-1")
@@ -233,7 +233,7 @@ def test_delete_dhcp_options():
     assert ex.value.response["Error"]["Code"] == "InvalidDhcpOptionID.NotFound"
 
 
-@mock_ec2
+@mock_aws
 def test_delete_dhcp_options_invalid_id():
     client = boto3.client("ec2", region_name="us-west-1")
 
@@ -244,7 +244,7 @@ def test_delete_dhcp_options_invalid_id():
     assert ex.value.response["Error"]["Code"] == "InvalidDhcpOptionID.NotFound"
 
 
-@mock_ec2
+@mock_aws
 def test_delete_dhcp_options_malformed_id():
     client = boto3.client("ec2", region_name="us-west-1")
 
@@ -255,7 +255,7 @@ def test_delete_dhcp_options_malformed_id():
     assert ex.value.response["Error"]["Code"] == "InvalidDhcpOptionsId.Malformed"
 
 
-@mock_ec2
+@mock_aws
 def test_dhcp_tagging():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -285,7 +285,7 @@ def test_dhcp_tagging():
     assert dhcp_option["Tags"] == [{"Key": "a tag", "Value": tag_value}]
 
 
-@mock_ec2
+@mock_aws
 def test_dhcp_options_get_by_tag():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -361,7 +361,7 @@ def test_dhcp_options_get_by_tag():
     assert len(dhcp_options_sets) == 2
 
 
-@mock_ec2
+@mock_aws
 def test_dhcp_options_get_by_id():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -404,7 +404,7 @@ def test_dhcp_options_get_by_id():
     assert d[0]["DhcpOptionsId"] == dhcp2.id
 
 
-@mock_ec2
+@mock_aws
 def test_dhcp_options_get_by_value_filter():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
 
@@ -438,7 +438,7 @@ def test_dhcp_options_get_by_value_filter():
     assert len(dhcp_options_sets) == 1
 
 
-@mock_ec2
+@mock_aws
 def test_dhcp_options_get_by_key_filter():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
 
@@ -458,9 +458,9 @@ def test_dhcp_options_get_by_key_filter():
 
     filters = [{"Name": "key", "Values": ["domain-name"]}]
     dhcp_options_sets = list(ec2.dhcp_options_sets.filter(Filters=filters))
-    assert (
-        len(dhcp_options_sets) >= 3
-    ), "Should have at least 3 DHCP options just created"
+    assert len(dhcp_options_sets) >= 3, (
+        "Should have at least 3 DHCP options just created"
+    )
 
     configs = []
     for d in dhcp_options_sets:
@@ -474,7 +474,7 @@ def test_dhcp_options_get_by_key_filter():
     assert {"Value": "example.com"} in servers
 
 
-@mock_ec2
+@mock_aws
 def test_dhcp_options_get_by_invalid_filter():
     if settings.TEST_SERVER_MODE:
         raise SkipTest("Will throw a generic 500 in ServerMode")
