@@ -4,22 +4,24 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_ec2, mock_logs, mock_s3
+from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 
-@mock_s3
-@mock_ec2
-def test_create_flow_logs_s3():
-    s3 = boto3.resource("s3", region_name="us-west-1")
-    client = boto3.client("ec2", region_name="us-west-1")
+@mock_aws
+@pytest.mark.parametrize(
+    "region,partition", [("us-west-2", "aws"), ("cn-north-1", "aws-cn")]
+)
+def test_create_flow_logs_s3(region, partition):
+    s3 = boto3.resource("s3", region_name=region)
+    client = boto3.client("ec2", region_name=region)
 
     vpc = client.create_vpc(CidrBlock="10.0.0.0/16")["Vpc"]
 
     bucket_name = str(uuid4())
     bucket = s3.create_bucket(
         Bucket=bucket_name,
-        CreateBucketConfiguration={"LocationConstraint": "us-west-1"},
+        CreateBucketConfiguration={"LocationConstraint": region},
     )
 
     with pytest.raises(ClientError) as ex:
@@ -66,8 +68,7 @@ def test_create_flow_logs_s3():
     assert flow_log["MaxAggregationInterval"] == 600
 
 
-@mock_s3
-@mock_ec2
+@mock_aws
 def test_create_multiple_flow_logs_s3():
     s3 = boto3.resource("s3", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -116,8 +117,33 @@ def test_create_multiple_flow_logs_s3():
     assert flow_log_1["LogDestination"] != flow_log_2["LogDestination"]
 
 
-@mock_logs
-@mock_ec2
+@mock_aws
+def test_create_flow_logs_s3__bucket_in_different_partition():
+    s3 = boto3.resource("s3", region_name="cn-north-1")
+    client = boto3.client("ec2", region_name="us-west-1")
+
+    vpc = client.create_vpc(CidrBlock="10.0.0.0/16")["Vpc"]
+
+    bucket_name = str(uuid4())
+    bucket = s3.create_bucket(
+        Bucket=bucket_name,
+        CreateBucketConfiguration={"LocationConstraint": "cn-north-1"},
+    )
+
+    response = client.create_flow_logs(
+        ResourceType="VPC",
+        ResourceIds=[vpc["VpcId"]],
+        TrafficType="ALL",
+        LogDestinationType="s3",
+        LogDestination="arn:aws:s3:::" + bucket.name,
+    )["FlowLogIds"]
+    assert len(response) == 1
+
+    flow_logs = client.describe_flow_logs(FlowLogIds=[response[0]])["FlowLogs"]
+    assert len(flow_logs) == 1
+
+
+@mock_aws
 def test_create_flow_logs_cloud_watch():
     client = boto3.client("ec2", region_name="us-west-1")
     logs_client = boto3.client("logs", region_name="us-west-1")
@@ -178,8 +204,7 @@ def test_create_flow_logs_cloud_watch():
     assert flow_log["MaxAggregationInterval"] == 600
 
 
-@mock_logs
-@mock_ec2
+@mock_aws
 def test_create_multiple_flow_logs_cloud_watch():
     client = boto3.client("ec2", region_name="us-west-1")
     logs_client = boto3.client("logs", region_name="us-west-1")
@@ -223,8 +248,7 @@ def test_create_multiple_flow_logs_cloud_watch():
     assert flow_log_1["LogGroupName"] != flow_log_2["LogGroupName"]
 
 
-@mock_s3
-@mock_ec2
+@mock_aws
 def test_create_flow_log_create():
     s3 = boto3.resource("s3", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -260,8 +284,7 @@ def test_create_flow_log_create():
     )
 
 
-@mock_s3
-@mock_ec2
+@mock_aws
 def test_delete_flow_logs():
     s3 = boto3.resource("s3", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -299,8 +322,7 @@ def test_delete_flow_logs():
     assert len(flow_logs) == 0
 
 
-@mock_s3
-@mock_ec2
+@mock_aws
 def test_delete_flow_logs_delete_many():
     s3 = boto3.resource("s3", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -333,7 +355,7 @@ def test_delete_flow_logs_delete_many():
         assert fl_id not in all_ids
 
 
-@mock_ec2
+@mock_aws
 def test_delete_flow_logs_non_existing():
     client = boto3.client("ec2", region_name="us-west-1")
 
@@ -356,7 +378,7 @@ def test_delete_flow_logs_non_existing():
     )
 
 
-@mock_ec2
+@mock_aws
 def test_create_flow_logs_unsuccessful():
     client = boto3.client("ec2", region_name="us-west-1")
 
@@ -382,8 +404,7 @@ def test_create_flow_logs_unsuccessful():
     assert error2["Message"] == "LogDestination: non-existing-bucket does not exist."
 
 
-@mock_s3
-@mock_ec2
+@mock_aws
 def test_create_flow_logs_invalid_parameters():
     s3 = boto3.resource("s3", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -504,9 +525,7 @@ def test_create_flow_logs_invalid_parameters():
     )
 
 
-@mock_s3
-@mock_ec2
-@mock_logs
+@mock_aws
 def test_describe_flow_logs_filtering():
     s3 = boto3.resource("s3", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -667,8 +686,7 @@ def test_describe_flow_logs_filtering():
         client.describe_flow_logs(Filters=[{"Name": "unknown", "Values": ["foobar"]}])
 
 
-@mock_s3
-@mock_ec2
+@mock_aws
 def test_flow_logs_by_ids():
     client = boto3.client("ec2", region_name="us-west-1")
 
@@ -730,7 +748,7 @@ def test_flow_logs_by_ids():
     assert fl3 not in all_ids
 
 
-def retrieve_all_logs(client, filters=[]):  # pylint: disable=W0102
+def retrieve_all_logs(client, filters=[]):
     resp = client.describe_flow_logs(Filters=filters)
     all_logs = resp["FlowLogs"]
     token = resp.get("NextToken")
