@@ -1,10 +1,10 @@
 import boto3
 import pytest
-
 from botocore.exceptions import ClientError
-from moto import mock_iot
 
-name = "my-rule"
+from moto import mock_aws
+
+name = "myrule"
 payload = {
     "sql": "SELECT * FROM 'topic/*' WHERE something > 0",
     "actions": [
@@ -19,7 +19,18 @@ payload = {
 }
 
 
-@mock_iot
+@mock_aws
+@pytest.mark.parametrize("invalid_name", ["t-r", "t.r", "t r"])
+def test_topic_rule_create_with_invalid_name(invalid_name):
+    client = boto3.client("iot", region_name="us-east-1")
+    with pytest.raises(ClientError) as exc:
+        client.create_topic_rule(ruleName=invalid_name, topicRulePayload=payload)
+    err = exc.value.response["Error"]
+    assert err["Code"] == "InvalidRequestException"
+    assert "Member must satisfy regular expression pattern" in err["Message"]
+
+
+@mock_aws
 def test_topic_rule_create():
     client = boto3.client("iot", region_name="ap-northeast-1")
 
@@ -29,31 +40,31 @@ def test_topic_rule_create():
     with pytest.raises(ClientError) as ex:
         client.create_topic_rule(ruleName=name, topicRulePayload=payload)
     error_code = ex.value.response["Error"]["Code"]
-    error_code.should.equal("ResourceAlreadyExistsException")
+    assert error_code == "ResourceAlreadyExistsException"
 
 
-@mock_iot
+@mock_aws
 def test_topic_rule_list():
     client = boto3.client("iot", region_name="ap-northeast-1")
 
     # empty response
     res = client.list_topic_rules()
-    res.should.have.key("rules").which.should.have.length_of(0)
+    assert len(res["rules"]) == 0
 
     client.create_topic_rule(ruleName=name, topicRulePayload=payload)
-    client.create_topic_rule(ruleName="my-rule-2", topicRulePayload=payload)
+    client.create_topic_rule(ruleName=f"{name}2", topicRulePayload=payload)
 
     res = client.list_topic_rules()
-    res.should.have.key("rules").which.should.have.length_of(2)
-    for rule, rule_name in zip(res["rules"], [name, "my-rule-2"]):
-        rule.should.have.key("ruleName").which.should.equal(rule_name)
-        rule.should.have.key("createdAt").which.should_not.be.none
-        rule.should.have.key("ruleArn").which.should_not.be.none
-        rule.should.have.key("ruleDisabled").which.should.equal(payload["ruleDisabled"])
-        rule.should.have.key("topicPattern").which.should.equal("topic/*")
+    assert len(res["rules"]) == 2
+    for rule, rule_name in zip(res["rules"], [name, f"{name}2"]):
+        assert rule["ruleName"] == rule_name
+        assert rule["createdAt"] is not None
+        assert rule["ruleArn"] is not None
+        assert rule["ruleDisabled"] == payload["ruleDisabled"]
+        assert rule["topicPattern"] == "topic/*"
 
 
-@mock_iot
+@mock_aws
 def test_topic_rule_get():
     client = boto3.client("iot", region_name="ap-northeast-1")
 
@@ -61,28 +72,25 @@ def test_topic_rule_get():
     with pytest.raises(ClientError) as ex:
         client.get_topic_rule(ruleName=name)
     error_code = ex.value.response["Error"]["Code"]
-    error_code.should.equal("ResourceNotFoundException")
+    assert error_code == "ResourceNotFoundException"
 
     client.create_topic_rule(ruleName=name, topicRulePayload=payload)
 
     rule = client.get_topic_rule(ruleName=name)
 
-    rule.should.have.key("ruleArn").which.should_not.be.none
-    rule.should.have.key("rule")
+    assert rule["ruleArn"] is not None
     rrule = rule["rule"]
-    rrule.should.have.key("actions").which.should.equal(payload["actions"])
-    rrule.should.have.key("awsIotSqlVersion").which.should.equal(
-        payload["awsIotSqlVersion"]
-    )
-    rrule.should.have.key("createdAt").which.should_not.be.none
-    rrule.should.have.key("description").which.should.equal(payload["description"])
-    rrule.should.have.key("errorAction").which.should.equal(payload["errorAction"])
-    rrule.should.have.key("ruleDisabled").which.should.equal(payload["ruleDisabled"])
-    rrule.should.have.key("ruleName").which.should.equal(name)
-    rrule.should.have.key("sql").which.should.equal(payload["sql"])
+    assert rrule["actions"] == payload["actions"]
+    assert rrule["awsIotSqlVersion"] == payload["awsIotSqlVersion"]
+    assert rrule["createdAt"] is not None
+    assert rrule["description"] == payload["description"]
+    assert rrule["errorAction"] == payload["errorAction"]
+    assert rrule["ruleDisabled"] == payload["ruleDisabled"]
+    assert rrule["ruleName"] == name
+    assert rrule["sql"] == payload["sql"]
 
 
-@mock_iot
+@mock_aws
 def test_topic_rule_replace():
     client = boto3.client("iot", region_name="ap-northeast-1")
 
@@ -90,7 +98,7 @@ def test_topic_rule_replace():
     with pytest.raises(ClientError) as ex:
         client.replace_topic_rule(ruleName=name, topicRulePayload=payload)
     error_code = ex.value.response["Error"]["Code"]
-    error_code.should.equal("ResourceNotFoundException")
+    assert error_code == "ResourceNotFoundException"
 
     client.create_topic_rule(ruleName=name, topicRulePayload=payload)
 
@@ -99,11 +107,11 @@ def test_topic_rule_replace():
     client.replace_topic_rule(ruleName=name, topicRulePayload=my_payload)
 
     rule = client.get_topic_rule(ruleName=name)
-    rule["rule"]["ruleName"].should.equal(name)
-    rule["rule"]["description"].should.equal(my_payload["description"])
+    assert rule["rule"]["ruleName"] == name
+    assert rule["rule"]["description"] == my_payload["description"]
 
 
-@mock_iot
+@mock_aws
 def test_topic_rule_disable():
     client = boto3.client("iot", region_name="ap-northeast-1")
 
@@ -111,18 +119,18 @@ def test_topic_rule_disable():
     with pytest.raises(ClientError) as ex:
         client.disable_topic_rule(ruleName=name)
     error_code = ex.value.response["Error"]["Code"]
-    error_code.should.equal("ResourceNotFoundException")
+    assert error_code == "ResourceNotFoundException"
 
     client.create_topic_rule(ruleName=name, topicRulePayload=payload)
 
     client.disable_topic_rule(ruleName=name)
 
     rule = client.get_topic_rule(ruleName=name)
-    rule["rule"]["ruleName"].should.equal(name)
-    rule["rule"]["ruleDisabled"].should.equal(True)
+    assert rule["rule"]["ruleName"] == name
+    assert rule["rule"]["ruleDisabled"] is True
 
 
-@mock_iot
+@mock_aws
 def test_topic_rule_enable():
     client = boto3.client("iot", region_name="ap-northeast-1")
 
@@ -130,7 +138,7 @@ def test_topic_rule_enable():
     with pytest.raises(ClientError) as ex:
         client.enable_topic_rule(ruleName=name)
     error_code = ex.value.response["Error"]["Code"]
-    error_code.should.equal("ResourceNotFoundException")
+    assert error_code == "ResourceNotFoundException"
 
     my_payload = payload.copy()
     my_payload["ruleDisabled"] = True
@@ -139,11 +147,11 @@ def test_topic_rule_enable():
     client.enable_topic_rule(ruleName=name)
 
     rule = client.get_topic_rule(ruleName=name)
-    rule["rule"]["ruleName"].should.equal(name)
-    rule["rule"]["ruleDisabled"].should.equal(False)
+    assert rule["rule"]["ruleName"] == name
+    assert rule["rule"]["ruleDisabled"] is False
 
 
-@mock_iot
+@mock_aws
 def test_topic_rule_delete():
     client = boto3.client("iot", region_name="ap-northeast-1")
 
@@ -151,7 +159,7 @@ def test_topic_rule_delete():
     with pytest.raises(ClientError) as ex:
         client.delete_topic_rule(ruleName=name)
     error_code = ex.value.response["Error"]["Code"]
-    error_code.should.equal("ResourceNotFoundException")
+    assert error_code == "ResourceNotFoundException"
 
     client.create_topic_rule(ruleName=name, topicRulePayload=payload)
 
@@ -160,4 +168,4 @@ def test_topic_rule_delete():
     client.delete_topic_rule(ruleName=name)
 
     res = client.list_topic_rules()
-    res.should.have.key("rules").which.should.have.length_of(0)
+    assert len(res["rules"]) == 0
