@@ -44,14 +44,12 @@ def test_create_cluster_boto3():
             "ParameterApplyStatus": "in-sync",
         }
     ]
-    assert cluster["ClusterSubnetGroupName"] == ""
     assert cluster["AvailabilityZone"] == "us-east-1a"
     assert cluster["PreferredMaintenanceWindow"] == "Mon:03:00-Mon:03:30"
     assert cluster["ClusterVersion"] == "1.0"
     assert cluster["AllowVersionUpgrade"] is True
     assert cluster["NumberOfNodes"] == 1
     assert cluster["EnhancedVpcRouting"] is False
-    assert cluster["KmsKeyId"] == ""
     assert cluster["Endpoint"]["Port"] == 5439
 
 
@@ -591,7 +589,7 @@ def test_authorize_security_group_ingress():
         client.authorize_cluster_security_group_ingress(
             ClusterSecurityGroupName="invalid_security_group", CIDRIP="192.168.10.0/28"
         )
-    assert ex.value.response["Error"]["Code"] == "ClusterSecurityGroupNotFoundFault"
+    assert ex.value.response["Error"]["Code"] == "ClusterSecurityGroupNotFound"
 
     assert (
         ex.value.response["Error"]["Message"]
@@ -619,7 +617,7 @@ def test_describe_non_existent_subnet_group_boto3():
     with pytest.raises(ClientError) as ex:
         client.describe_cluster_subnet_groups(ClusterSubnetGroupName="my_subnet")
     err = ex.value.response["Error"]
-    assert err["Code"] == "ClusterSubnetGroupNotFound"
+    assert err["Code"] == "ClusterSubnetGroupNotFoundFault"
     assert err["Message"] == "Subnet group my_subnet not found."
 
 
