@@ -1,17 +1,23 @@
 import json
+import unittest
 
 import pytest
 
-from moto import mock_s3
+from moto import mock_aws, settings
 from moto.core.exceptions import InvalidNextTokenException
 from moto.s3.config import s3_config_query
 from tests import DEFAULT_ACCOUNT_ID
 
-s3_config_query_backend = s3_config_query.backends[DEFAULT_ACCOUNT_ID]["global"]
+# Integration tests would use `boto3.client("config").list_discovered_resources`
+# We're testing the backend here directly, because it is much quicker
 
 
-@mock_s3
+@mock_aws
 def test_s3_public_access_block_to_config_dict():
+    if not settings.TEST_DECORATOR_MODE:
+        raise unittest.SkipTest("Not using boto3 - no point in testing server-mode")
+    s3_config_query_backend = s3_config_query.backends[DEFAULT_ACCOUNT_ID]["global"]
+
     # With 1 bucket in us-west-2:
     s3_config_query_backend.create_bucket("bucket1", "us-west-2")
 
@@ -43,8 +49,12 @@ def test_s3_public_access_block_to_config_dict():
     )
 
 
-@mock_s3
+@mock_aws
 def test_list_config_discovered_resources():
+    if not settings.TEST_DECORATOR_MODE:
+        raise unittest.SkipTest("Not using boto3 - no point in testing server-mode")
+    s3_config_query_backend = s3_config_query.backends[DEFAULT_ACCOUNT_ID]["global"]
+
     # Without any buckets:
     assert s3_config_query.list_config_service_resources(
         "global", "global", None, None, 100, None
@@ -59,7 +69,7 @@ def test_list_config_discovered_resources():
         s3_config_query_backend.create_bucket(f"eu-bucket{idx}", "eu-west-1")
 
     result, next_token = s3_config_query.list_config_service_resources(
-        DEFAULT_ACCOUNT_ID, None, None, 100, None
+        DEFAULT_ACCOUNT_ID, "aws", None, None, 100, None
     )
     assert not next_token
     assert len(result) == 12
@@ -80,19 +90,19 @@ def test_list_config_discovered_resources():
 
     # With a name:
     result, next_token = s3_config_query.list_config_service_resources(
-        DEFAULT_ACCOUNT_ID, None, "bucket0", 100, None
+        DEFAULT_ACCOUNT_ID, "aws", None, "bucket0", 100, None
     )
     assert len(result) == 1 and result[0]["name"] == "bucket0" and not next_token
 
     # With a region:
     result, next_token = s3_config_query.list_config_service_resources(
-        DEFAULT_ACCOUNT_ID, None, None, 100, None, resource_region="eu-west-1"
+        DEFAULT_ACCOUNT_ID, "aws", None, None, 100, None, resource_region="eu-west-1"
     )
     assert len(result) == 2 and not next_token and result[1]["name"] == "eu-bucket11"
 
     # With resource ids:
     result, next_token = s3_config_query.list_config_service_resources(
-        DEFAULT_ACCOUNT_ID, ["bucket0", "bucket1"], None, 100, None
+        DEFAULT_ACCOUNT_ID, "aws", ["bucket0", "bucket1"], None, 100, None
     )
     assert (
         len(result) == 2
@@ -103,13 +113,13 @@ def test_list_config_discovered_resources():
 
     # With duplicated resource ids:
     result, next_token = s3_config_query.list_config_service_resources(
-        DEFAULT_ACCOUNT_ID, ["bucket0", "bucket0"], None, 100, None
+        DEFAULT_ACCOUNT_ID, "aws", ["bucket0", "bucket0"], None, 100, None
     )
     assert len(result) == 1 and result[0]["name"] == "bucket0" and not next_token
 
     # Pagination:
     result, next_token = s3_config_query.list_config_service_resources(
-        DEFAULT_ACCOUNT_ID, None, None, 1, None
+        DEFAULT_ACCOUNT_ID, "aws", None, None, 1, None
     )
     assert (
         len(result) == 1 and result[0]["name"] == "bucket0" and next_token == "bucket1"
@@ -117,13 +127,19 @@ def test_list_config_discovered_resources():
 
     # Last Page:
     result, next_token = s3_config_query.list_config_service_resources(
-        DEFAULT_ACCOUNT_ID, None, None, 1, "eu-bucket11", resource_region="eu-west-1"
+        DEFAULT_ACCOUNT_ID,
+        "aws",
+        None,
+        None,
+        1,
+        "eu-bucket11",
+        resource_region="eu-west-1",
     )
     assert len(result) == 1 and result[0]["name"] == "eu-bucket11" and not next_token
 
     # With a list of buckets:
     result, next_token = s3_config_query.list_config_service_resources(
-        DEFAULT_ACCOUNT_ID, ["bucket0", "bucket1"], None, 1, None
+        DEFAULT_ACCOUNT_ID, "aws", ["bucket0", "bucket1"], None, 1, None
     )
     assert (
         len(result) == 1 and result[0]["name"] == "bucket0" and next_token == "bucket1"
@@ -132,14 +148,18 @@ def test_list_config_discovered_resources():
     # With an invalid page:
     with pytest.raises(InvalidNextTokenException) as inte:
         s3_config_query.list_config_service_resources(
-            DEFAULT_ACCOUNT_ID, None, None, 1, "notabucket"
+            DEFAULT_ACCOUNT_ID, "aws", None, None, 1, "notabucket"
         )
 
     assert "The nextToken provided is invalid" in inte.value.message
 
 
-@mock_s3
+@mock_aws
 def test_s3_lifecycle_config_dict():
+    if not settings.TEST_DECORATOR_MODE:
+        raise unittest.SkipTest("Not using boto3 - no point in testing server-mode")
+    s3_config_query_backend = s3_config_query.backends[DEFAULT_ACCOUNT_ID]["global"]
+
     # With 1 bucket in us-west-2:
     s3_config_query_backend.create_bucket("bucket1", "us-west-2")
 
@@ -278,8 +298,12 @@ def test_s3_lifecycle_config_dict():
     }
 
 
-@mock_s3
+@mock_aws
 def test_s3_notification_config_dict():
+    if not settings.TEST_DECORATOR_MODE:
+        raise unittest.SkipTest("Not using boto3 - no point in testing server-mode")
+    s3_config_query_backend = s3_config_query.backends[DEFAULT_ACCOUNT_ID]["global"]
+
     # With 1 bucket in us-west-2:
     s3_config_query_backend.create_bucket("bucket1", "us-west-2")
 
@@ -321,6 +345,7 @@ def test_s3_notification_config_dict():
                 },
             }
         ],
+        "EventBridgeConfiguration": {},
     }
 
     s3_config_query.backends[DEFAULT_ACCOUNT_ID][
@@ -371,12 +396,17 @@ def test_s3_notification_config_dict():
                 "queueARN": "arn:aws:lambda:us-west-2:012345678910:function:mylambda",
                 "type": "LambdaConfiguration",
             },
+            "EventBridgeConfiguration": {},
         }
     }
 
 
-@mock_s3
+@mock_aws
 def test_s3_acl_to_config_dict():
+    if not settings.TEST_DECORATOR_MODE:
+        raise unittest.SkipTest("Not using boto3 - no point in testing server-mode")
+    s3_config_query_backend = s3_config_query.backends[DEFAULT_ACCOUNT_ID]["global"]
+
     from moto.s3.models import OWNER, FakeAcl, FakeGrant, FakeGrantee
 
     # With 1 bucket in us-west-2:
@@ -446,12 +476,18 @@ def test_s3_acl_to_config_dict():
     }
 
 
-@mock_s3
+@mock_aws
 def test_s3_config_dict():
+    if not settings.TEST_DECORATOR_MODE:
+        raise unittest.SkipTest("Not using boto3 - no point in testing server-mode")
+    s3_config_query_backend = s3_config_query.backends[DEFAULT_ACCOUNT_ID]["global"]
+
     from moto.s3.models import OWNER, FakeAcl, FakeGrant, FakeGrantee
 
     # Without any buckets:
-    assert not s3_config_query.get_config_resource(DEFAULT_ACCOUNT_ID, "some_bucket")
+    assert not s3_config_query.get_config_resource(
+        DEFAULT_ACCOUNT_ID, "aws", "some_bucket"
+    )
 
     tags = {"someTag": "someValue", "someOtherTag": "someOtherValue"}
 
@@ -498,7 +534,9 @@ def test_s3_config_dict():
     s3_config_query_backend.put_bucket_policy("bucket1", pass_policy)
 
     # Get the us-west-2 bucket and verify that it works properly:
-    bucket1_result = s3_config_query.get_config_resource(DEFAULT_ACCOUNT_ID, "bucket1")
+    bucket1_result = s3_config_query.get_config_resource(
+        DEFAULT_ACCOUNT_ID, "aws", "bucket1"
+    )
 
     # Just verify a few things:
     assert bucket1_result["arn"] == "arn:aws:s3:::bucket1"
@@ -555,32 +593,32 @@ def test_s3_config_dict():
 
     # Filter by correct region:
     assert bucket1_result == s3_config_query.get_config_resource(
-        DEFAULT_ACCOUNT_ID, "bucket1", resource_region="us-west-2"
+        DEFAULT_ACCOUNT_ID, "aws", "bucket1", resource_region="us-west-2"
     )
 
     # By incorrect region:
     assert not s3_config_query.get_config_resource(
-        DEFAULT_ACCOUNT_ID, "bucket1", resource_region="eu-west-1"
+        DEFAULT_ACCOUNT_ID, "aws", "bucket1", resource_region="eu-west-1"
     )
 
     # With correct resource ID and name:
     assert bucket1_result == s3_config_query.get_config_resource(
-        DEFAULT_ACCOUNT_ID, "bucket1", resource_name="bucket1"
+        DEFAULT_ACCOUNT_ID, "aws", "bucket1", resource_name="bucket1"
     )
 
     # With an incorrect resource name:
     assert not s3_config_query.get_config_resource(
-        DEFAULT_ACCOUNT_ID, "bucket1", resource_name="eu-bucket-1"
+        DEFAULT_ACCOUNT_ID, "aws", "bucket1", resource_name="eu-bucket-1"
     )
 
     # With an incorrect account:
     assert not s3_config_query.get_config_resource(
-        "unknown-accountid", "bucket1", resource_name="bucket-1"
+        "unknown-accountid", "aws", "bucket1", resource_name="bucket-1"
     )
 
     # Verify that no bucket policy returns the proper value:
     logging_bucket = s3_config_query.get_config_resource(
-        DEFAULT_ACCOUNT_ID, "logbucket"
+        DEFAULT_ACCOUNT_ID, "aws", "logbucket"
     )
     assert json.loads(logging_bucket["supplementaryConfiguration"]["BucketPolicy"]) == {
         "policyText": None
