@@ -4,7 +4,7 @@ from uuid import uuid4
 import boto3
 import pytest
 
-from moto import mock_lambda, mock_logs, mock_s3, mock_sns, mock_sqs
+from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from tests.markers import requires_docker
 from tests.test_awslambda.utilities import (
@@ -16,9 +16,7 @@ from tests.test_awslambda.utilities import (
 REGION_NAME = "us-east-1"
 
 
-@mock_lambda
-@mock_logs
-@mock_s3
+@mock_aws
 @pytest.mark.parametrize(
     "match_events,actual_event",
     [
@@ -68,7 +66,7 @@ def test_objectcreated_put__invokes_lambda(match_events, actual_event):
     )
 
     # Put Object
-    s3_client.put_object(Bucket=bucket_name, Key="keyname", Body="bodyofnewobject")
+    s3_client.put_object(Bucket=bucket_name, Key="key name", Body="bodyofnewobject")
 
     # Find the output of AWSLambda
     expected_msg = "FINISHED_PRINTING_EVENT"
@@ -102,12 +100,11 @@ def test_objectcreated_put__invokes_lambda(match_events, actual_event):
     assert records[0]["s3"]["configurationId"] == "s3eventtriggerslambda"
     assert "object" in records[0]["s3"]
     assert records[0]["s3"]["object"]["eTag"] == "61ea96c3c8d2c76fc5a42bfccb6affd9"
-    assert records[0]["s3"]["object"]["key"] == "keyname"
+    assert records[0]["s3"]["object"]["key"] == "key+name"
     assert records[0]["s3"]["object"]["size"] == 15
 
 
-@mock_logs
-@mock_s3
+@mock_aws
 def test_objectcreated_put__unknown_lambda_is_handled_gracefully():
     s3_res = boto3.resource("s3", region_name=REGION_NAME)
     s3_client = boto3.client("s3", region_name=REGION_NAME)
@@ -139,8 +136,7 @@ def test_objectcreated_put__unknown_lambda_is_handled_gracefully():
     assert resp["Body"].read() == b"bodyofnewobject"
 
 
-@mock_s3
-@mock_sqs
+@mock_aws
 def test_object_copy__sends_to_queue():
     s3_res = boto3.resource("s3", region_name=REGION_NAME)
     s3_client = boto3.client("s3", region_name=REGION_NAME)
@@ -182,7 +178,7 @@ def test_object_copy__sends_to_queue():
     # Copy an Object
     s3_client.put_object(Bucket=bucket_name, Key="keyname", Body="bodyofnewobject")
     s3_client.copy_object(
-        Bucket=bucket_name, CopySource=f"{bucket_name}/keyname", Key="key2"
+        Bucket=bucket_name, CopySource=f"{bucket_name}/keyname", Key="key!"
     )
 
     # Read SQS messages - we should have the Copy-event here
@@ -202,12 +198,11 @@ def test_object_copy__sends_to_queue():
     assert records[0]["s3"]["configurationId"] == "queue_config"
     assert "object" in records[0]["s3"]
     assert records[0]["s3"]["object"]["eTag"] == "61ea96c3c8d2c76fc5a42bfccb6affd9"
-    assert records[0]["s3"]["object"]["key"] == "key2"
+    assert records[0]["s3"]["object"]["key"] == "key%21"
     assert records[0]["s3"]["object"]["size"] == 15
 
 
-@mock_s3
-@mock_sqs
+@mock_aws
 def test_object_put__sends_to_queue__using_filter():
     s3_res = boto3.resource("s3", region_name=REGION_NAME)
     s3_client = boto3.client("s3", region_name=REGION_NAME)
@@ -286,20 +281,23 @@ def test_object_put__sends_to_queue__using_filter():
     _ = [m.delete() for m in messages]
 
 
-@mock_s3
-@mock_sns
-@mock_sqs
-def test_put_bucket_notification_sns_sqs():
-    s3_client = boto3.client("s3", region_name=REGION_NAME)
-    s3_client.create_bucket(Bucket="bucket")
+@mock_aws
+@pytest.mark.parametrize(
+    "region,partition", [("us-west-2", "aws"), ("cn-north-1", "aws-cn")]
+)
+def test_put_bucket_notification_sns_sqs(region, partition):
+    s3_client = boto3.client("s3", region_name=region)
+    s3_client.create_bucket(
+        Bucket="bucket", CreateBucketConfiguration={"LocationConstraint": region}
+    )
 
-    sqs_client = boto3.client("sqs", region_name=REGION_NAME)
+    sqs_client = boto3.client("sqs", region_name=region)
     sqs_queue = sqs_client.create_queue(QueueName="queue")
     sqs_queue_arn = sqs_client.get_queue_attributes(
         QueueUrl=sqs_queue["QueueUrl"], AttributeNames=["QueueArn"]
     )
 
-    sns_client = boto3.client("sns", region_name=REGION_NAME)
+    sns_client = boto3.client("sns", region_name=region)
     sns_topic = sns_client.create_topic(Name="topic")
 
     # Subscribe SQS queue to SNS topic
@@ -359,9 +357,14 @@ def test_put_bucket_notification_sns_sqs():
     # Get S3 notification from SNS message
     s3_message_body = json.loads(sns_message["Message"])
     assert s3_message_body["Records"][0]["eventName"] == "ObjectCreated:Put"
+    assert s3_message_body["Records"][0]["awsRegion"] == region
+    assert (
+        s3_message_body["Records"][0]["s3"]["bucket"]["arn"]
+        == f"arn:{partition}:s3:::bucket"
+    )
 
 
-@mock_s3
+@mock_aws
 def test_put_bucket_notification_sns_error():
     s3_client = boto3.client("s3", region_name=REGION_NAME)
     s3_client.create_bucket(Bucket="bucket")
