@@ -8,9 +8,8 @@ import boto3
 import botocore
 import pytest
 
-from moto import mock_sagemaker, settings
+from moto import mock_aws, settings
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
-from moto.s3 import mock_s3
 from moto.sagemaker.exceptions import ValidationError
 from moto.sagemaker.models import FakePipeline, sagemaker_backends
 from moto.sagemaker.utils import (
@@ -27,7 +26,7 @@ TEST_REGION_NAME = "us-west-1"
 
 @contextmanager
 def setup_s3_pipeline_definition(bucket_name, object_key, pipeline_definition):
-    client = boto3.client("s3")
+    client = boto3.client("s3", TEST_REGION_NAME)
     client.create_bucket(
         Bucket=bucket_name,
         CreateBucketConfiguration={"LocationConstraint": TEST_REGION_NAME},
@@ -45,7 +44,7 @@ def setup_s3_pipeline_definition(bucket_name, object_key, pipeline_definition):
 
 @pytest.fixture(name="sagemaker_client")
 def fixture_sagemaker_client():
-    with mock_sagemaker():
+    with mock_aws():
         yield boto3.client("sagemaker", region_name=TEST_REGION_NAME)
 
 
@@ -283,7 +282,7 @@ def test_load_pipeline_definition_from_s3():
     object_key = "some/object/key.json"
     pipeline_definition = {"key": "value"}
 
-    with mock_s3():
+    with mock_aws():
         with setup_s3_pipeline_definition(
             bucket_name,
             object_key,
@@ -295,6 +294,7 @@ def test_load_pipeline_definition_from_s3():
                     "ObjectKey": object_key,
                 },
                 account_id=ACCOUNT_ID,
+                partition="aws",
             )
     assert observed_pipeline_definition == pipeline_definition
 
@@ -608,22 +608,6 @@ def test_update_pipeline_not_exists(sagemaker_client):
         _ = sagemaker_client.update_pipeline(PipelineName="some-pipeline-name")
 
 
-def test_update_pipeline_invalid_kwargs(sagemaker_client):
-    pipeline_name = "APipelineName"
-    pipeline = {
-        "PipelineName": pipeline_name,
-        "RoleArn": FAKE_ROLE_ARN,
-        "PipelineDefinition": " ",
-    }
-    _ = create_sagemaker_pipelines(sagemaker_client, [pipeline])
-
-    with pytest.raises(botocore.exceptions.ParamValidationError):
-        sagemaker_client.update_pipeline(
-            PipelineName=pipeline_name,
-            **{"InvalidKwarg": "some-value"},
-        )
-
-
 def test_update_pipeline_no_update(sagemaker_client):
     pipeline_name = "APipelineName"
     pipeline = {
