@@ -530,7 +530,7 @@ def test_create_fifo_topic():
     try:
         conn.create_topic(Name="test_topic", Attributes={"FifoTopic": "true"})
     except ClientError as err:
-        assert err.response["Error"]["Code"] == "InvalidParameterValue"
+        assert err.response["Error"]["Code"] == "InvalidParameter"
         assert err.response["Error"]["Message"] == (
             "Fifo Topic names must end with .fifo and must be made up of only "
             "uppercase and lowercase ASCII letters, numbers, underscores, "
@@ -541,7 +541,7 @@ def test_create_fifo_topic():
     try:
         conn.create_topic(Name="test_topic.fifo")
     except ClientError as err:
-        assert err.response["Error"]["Code"] == "InvalidParameterValue"
+        assert err.response["Error"]["Code"] == "InvalidParameter"
         assert err.response["Error"]["Message"] == (
             "Topic names must be made up of only uppercase and lowercase "
             "ASCII letters, numbers, underscores, "
@@ -551,7 +551,7 @@ def test_create_fifo_topic():
     try:
         conn.create_topic(Name="topic.name.fifo", Attributes={"FifoTopic": "true"})
     except ClientError as err:
-        assert err.response["Error"]["Code"] == "InvalidParameterValue"
+        assert err.response["Error"]["Code"] == "InvalidParameter"
         assert err.response["Error"]["Message"] == (
             "Fifo Topic names must end with .fifo and must be made up of only "
             "uppercase and lowercase ASCII letters, numbers, underscores, "
